@@ -5,6 +5,8 @@ while (<>) {
 	s/&/&amp;/g;
 	s/\</&lt;/g;
 	s/\>/&gt;/g;
+	s/\\'/'/g;
+	s/\\-/-/g;
 	if ($printtable == 1) {
 		$printtable = 2;
 	} elsif ($printtable == 2) {
@@ -38,6 +40,12 @@ while (<>) {
 			print "</TD></TR></TABLE>\n";
 		}
 		print "<P>\n";
+	} elsif (/^\.IP/) {
+		if ($printtable == 3) {
+			$printtable = 0;
+			print "</TD></TR></TABLE>\n";
+		}
+		print "<P>\n";
 	} elsif (/^\.B "(.*)"$/) {
 		print "<B>$1</B>\n";
 	} elsif (/^\.B (.*)$/) {
@@ -78,7 +86,8 @@ while (<>) {
 	} else {
 		s/\\fB([^\\]*)\\fR/<B>\1<\/B>/gm;
 		s/\\fI([^\\]*)\\fR/<I>\1<\/I>/gm;
-		s/\\(.)/\1>/g;
+		s/&lt;([a-zA-Z0-9.]+\@[a-zA-Z0-9.]+)&gt;/&lt;<a href=\"mailto:\1\">\1<\/a>&gt;/g;
+		s/(http:\/\/[a-zA-Z0-9.\/~]+\.html)/<a href=\"\1\">\1<\/a>/g;
 		print;
 	}
 }
